@@ -1154,7 +1154,7 @@ static void show_colorsel(GtkWidget *widget,gpointer *data){
 	
 	LOG(LOG_DEBUG, "IN : show_colorsel()");
 	
-	color_no = (gint)data;
+	color_no = (gint)(intptr_t)data;
 
 
 	colorsel_dlg = gtk_color_selection_dialog_new(_("Choose Color"));
